/***************************************************************************
                          kbearSiteInfomanageriface.h  -  description
                             -------------------
    begin                : lör mar 16 2002
    copyright            : (C) 2003 by Björn Sahlström
    email                : kbjorn@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KBEARMANAGERIFACE_H
#define KBEARMANAGERIFACE_H

//////////////////////////////////////////////////////////////////////
// Qt specific include files
//////////////////////////////////////////////////////////////////////
// KDE specific include files
#include <dcopobject.h>
//////////////////////////////////////////////////////////////////////
#include "../../lib/interfaces/siteinfo.h"
#include "group.h"

using namespace KBear;
// Application specific include files
/**
  *@author Björn Sahlström
  */

class KBearSiteManagerDCOPIface : virtual public DCOPObject  {
	K_DCOP
k_dcop:
	/** */
	virtual ASYNC slotNewSite( SiteInfo site ) = 0;
	/**	*/
	virtual ASYNC slotSiteChanged( SiteInfo site, QString oldName ) = 0;
	/** */
	virtual ASYNC slotSiteRemoved( SiteInfo site ) = 0;
	/**	*/
	virtual ASYNC slotSiteMoved( SiteInfo site, QString oldParent, QString oldName ) = 0;
	/**	*/
	virtual ASYNC slotNewGroup( Group group ) = 0;
	/**	*/
	virtual ASYNC slotGroupChanged( Group group, QString oldName ) = 0;
	/**	*/
	virtual ASYNC slotGroupRemoved( Group group ) = 0;
	/**	*/
	virtual ASYNC slotGroupMoved( Group SiteInfo, QString oldParent ) = 0;
	/**	*/
	virtual ASYNC slotEncodingChanged( QString encoding ) = 0;
	/**	*/
	virtual ASYNC slotUpdateDatabase( QString domTree ) = 0;
	/**	*/
	virtual ASYNC slotInitialize() = 0;
	/**	*/
	virtual ASYNC slotImportOldSitemanager( QString ) = 0;
	/**	*/
//	virtual ASYNC setShowSystemTray( bool ) = 0;
	/** */
	virtual ASYNC setPlugInKonq( bool ) = 0;
};

#endif
